Module groups

Group components

Enums

GroupKind
Types of groups

Functions

match_for_balanced_group
Try to recognize either a start group or an end group token.
match_for_delimited_group
A closure that takes a slice of bytes and returns a PeekResult indicating whether the slice matches a delimited group.
match_group
A closure that takes a slice of bytes and returns a PeekResult indicating whether the slice matches a balanced group.