Module matchers

Module matchers 

Byte slice matchers.

Functions

match_char
Attempt to match a single character against a byte slice.
match_number
Attempt to match a number against a byte slice.
match_pattern
Attempt to match a byte slice against a byte slice.
match_string
Attempt to match a string against a byte slice. Stop matching when a punctuation character is encountered.