Enum Token

pub enum Token {
Show 29 variants OpenParen, CloseParen, Comma, Semicolon, Colon, Whitespace, GreaterThan, LessThan, Exclamation, Quote, DoubleQuote, Equal, Plus, Dash, Slash, Star, Percent, Ampersand, Pipe, Caret, Tilde, Dot, Question, At, Hash, Dollar, Backslash, Underscore, Sharp,
}
The token type

Variants



OpenParen

The “(” character



CloseParen

The ) character



Comma

The , character



Semicolon

The ; character



Colon

The : character



Whitespace

The whitespace character



GreaterThan

The > character



LessThan

The < character



Exclamation

The ! character



Quote

The ' character



DoubleQuote

The " character



Equal

The = character



Plus

The + character



Dash

The - character



Slash

The / character



Star

The * character



Percent

The % character



Ampersand

The & character



Pipe

The | character



Caret

The ^ character



Tilde

The ~ character



Dot

The . character



Question

The ? character



At

The @ character



Hash

The # character



Dollar

The $ character



Backslash

The \\ character



Underscore

The _ character



Sharp

The # character