pub struct Until<'a, T, V> { /* private fields */ }Expand description
A Peekable that peeks until the given element is found in the
Scanner.
This Peekable will temporarily advance the position of the Scanner to
find a match. If a match is found, the Scanner is rewound to the original
position and a PeekResult is returned. If no match is found, the Scanner
is rewound to the original position and an Err is returned.
Implementations