Module recognizer

Defines how to recognize an object.

Structs

Recognizer
A Recognizer is a type that wraps a Scanner and holds a successfully recognized value.

Traits

Recognizable
A trait that defines how to recognize an object.
RecognizeSelf

Functions

recognize
Recognize an object for the given scanner.