pub enum PeekResult<S, E> {
Found {
end_slice: usize,
start: S,
end: E,
},
NotFound,
}Expand description
The result of a peeking operation.
A PeekResult contains the result of attempting to match a Peekable
against the current position of a Scanner. If the match succeeds, a
Found is returned with the length of the end slice, the start of the
match, and the end of the match. If the match fails, a NotFound is
returned.
Variants